Analyze these recent coding sessions to create a comprehensive user profile.

User ID: {{ user_id }}
Recent Sessions ({{ num_sessions }} sessions):
{{ sessions_text }}

Create a user analysis including: overall description, intent/emotion distributions, preferences
For the preferences, pay attention to different kinds of preferences (e.g., interactional preferences, coding preferences, etc.)
- Interactional preferences: like how users prefer to communicate with the SWE agent, do they prefer concise or verbose responses, upfront or ongoing question timing, do they usually give short or long responses, etc.
- Coding preferences: like what kind of coding preferences they have, do they prefer TypeScript, React, Node.js, etc.
- Other preferences: special requirements for the SWE agent, etc.
