Please condense the following message to max {{ max_tokens }} tokens (do not exceed the limit, and do not add any extra information).
FOCUS: Keep the most important information that provides context for understanding a conversation.

Original message:
{{ content }}

Condensed version:
